@@ -10,9 +10,10 @@ rcs <- function(rwl, po, nyrs=NULL, f=0.5, biweight=TRUE, rc.out=FALSE,
         stop("minimum 'po' is 1")
     if(!all(is.int(po[, 2])))
         stop("each value in 'po' must be an integer")
-    rownames(rwl) <-  rownames(rwl) # guard against NULL names funniness
+    rwl2 <- rwl
+    rownames(rwl2) <- rownames(rwl2) # guard against NULL names funniness
 
-    rwl.ord <- apply(rwl, 2, sortByIndex)
+    rwl.ord <- apply(rwl2, 2, sortByIndex)
     rwca <- matrix(NA,
                    ncol=n.col,
                    nrow=sum(nrow(rwl.ord) + max(po[, 2])))
@@ -26,17 +27,20 @@ rcs <- function(rwl, po, nyrs=NULL, f=0.5, biweight=TRUE, rc.out=FALSE,
     else ca.m <- rowMeans(rwca, na.rm=TRUE)
 
     ## spline follows B&Q 2008 as 10% of the RC length
-    if(is.null(nyrs)) nyrs <- floor(length(na.omit(ca.m)) * 0.1)
-    tmp <- ffcsaps(y=na.omit(ca.m), nyrs=nyrs, f=f)
+    if(is.null(nyrs))
+        nyrs2 <- floor(length(na.omit(ca.m)) * 0.1)
+    else
+        nyrs2 <- nyrs
+    tmp <- ffcsaps(y=na.omit(ca.m), nyrs=nyrs2, f=f)
     rc <- rep(NA, nrow(rwca))
     rc[!is.na(ca.m)] <- tmp
     ## divide each series by curve
     rwica <- rwca/rc
     ## and restore to cal years
-    rwi <- rwl
+    rwi <- rwl2
     yrs <- as.numeric(rownames(rwi))
     for(i in 1:n.col){
-        series.yrs <- yr.range(rwl[, i], yr.vec=yrs)
+        series.yrs <- yr.range(rwl2[, i], yr.vec=yrs)
         first <- series.yrs[1]
         last <- series.yrs[2]
         ## check
