@@ -24,13 +24,13 @@ cor.with.limit <- function(limit, x, y) {
 ### Computes the correlation coefficients between different columns of x.
 cor.with.limit.upper <- function(limit, x) {
     n.x <- ncol(x) # caller makes sure that n.x >= 2
-    r.vec <- rep(NA_real_, n.x*(n.x-1)/2)
+    r.vec <- rep(NA_real_, n.x * (n.x - 1) / 2)
     good.x <- !is.na(x)
     k <- 0
-    for(i in 1:(n.x-1)){
+    for(i in 1:(n.x - 1)){
         good.i <- good.x[, i]
-        for(j in (i+1):n.x){
-            k <- k+1
+        for(j in (i + 1):n.x){
+            k <- k + 1
             good.both <- which(good.i & good.x[, j])
             if(length(good.both) >= limit)
                 r.vec[k] <- cor(x[good.both, i], x[good.both, j])
@@ -43,11 +43,11 @@ cor.with.limit.upper <- function(limit, x) {
 rwi.stats.running <- function(rwi, ids=NULL, period=c("max", "common"),
                               running.window=TRUE,
                               window.length=min(50, nrow(rwi)),
-                              window.overlap=floor(window.length/2),
+                              window.overlap=floor(window.length / 2),
                               first.start=NULL,
                               min.corr.overlap=min(30, window.length),
                               round.decimals=3){
-    period <- match.arg(period)
+    period2 <- match.arg(period)
 
     if(running.window){
         if(window.length < 3)
@@ -60,44 +60,46 @@ rwi.stats.running <- function(rwi, ids=NULL, period=c("max", "common"),
             stop("'window.length' is smaller than 'min.corr.overlap'")
     }
 
-    rwi <- as.matrix(rwi)
-    n.cores <- ncol(rwi)
+    rwi2 <- as.matrix(rwi)
+    n.cores <- ncol(rwi2)
 
     ## If tree.id is NULL then assume one core per tree
     if(is.null(ids)){
-        ids <- data.frame(tree=1:n.cores, core=rep(1, n.cores))
+        ids2 <- data.frame(tree=1:n.cores, core=rep(1, n.cores))
     } else{
         ## Make error checks here
         if(nrow(ids) != n.cores)
             stop("dimension problem: ", "'ncol(rwi)' != 'nrow(ids)'")
         if(!all(sapply(ids, is.numeric)))
             stop("'ids' must have numeric columns")
+        ids2 <- ids
     }
 
-    n.years <- nrow(rwi)
+    n.years <- nrow(rwi2)
     if(running.window && window.length > n.years)
         stop("'window.length' is larger than the number of years in 'rwi'")
 
-    unique.ids <- unique(ids$tree)
+    unique.ids <- unique(ids2$tree)
     n.trees <- length(unique.ids)
     if(n.trees < 2) stop("at least 2 trees are needed")
     cores.of.tree <- list()
     for(i in 1:n.trees)
-        cores.of.tree[[i]] <- which(ids$tree==unique.ids[i])
+        cores.of.tree[[i]] <- which(ids2$tree==unique.ids[i])
 
     ## n.trees.by.year is recorded before setting rows with missing
     ## data to NA
     tree.any <- matrix(FALSE, n.years, n.trees)
     for(i in 1:n.trees)
         tree.any[, i] <-
-            apply(!is.na(rwi[, ids$tree==unique.ids[i], drop=FALSE]), 1, any)
+            apply(!is.na(rwi2[, ids2$tree == unique.ids[i], drop=FALSE]),
+                  1, any)
     n.trees.by.year <- rowSums(tree.any)
     good.rows <- which(n.trees.by.year > 1)
 
     ## Easy way to force complete overlap of data
-    if(period == "common"){
-        bad.rows <- which(apply(is.na(rwi), 1, any))
-        rwi[bad.rows, ] <- NA
+    if(period2 == "common"){
+        bad.rows <- which(apply(is.na(rwi2), 1, any))
+        rwi2[bad.rows, ] <- NA
         good.rows <- setdiff(good.rows, bad.rows)
     }
 
@@ -108,42 +110,45 @@ rwi.stats.running <- function(rwi, ids=NULL, period=c("max", "common"),
         if(is.numeric(first.start)){
             if(first.start < 1)
                 stop("'first.start' too small, must be >= 1")
-            else if(first.start > n.years-window.length+1)
+            else if(first.start > n.years - window.length + 1)
                 stop("'first.start' too large")
+            first.start2 <- first.start
         } else{
             ## Select locations of running windows by maximizing the
             ## number of data points (sum of number of series for each
             ## selected year), but don't count rows with less than two
             ## trees
             min.offset <-
-                max(0, min(good.rows)-(window.length-min.corr.overlap)-1)
+                max(0, min(good.rows) - (window.length - min.corr.overlap) - 1)
             max.offset <-
-                min(min.offset+window.advance-1, n.years-window.length)
+                min(min.offset + window.advance - 1, n.years - window.length)
             offsets <- min.offset:max.offset
             n.offsets <- length(offsets)
             n.data <- rep(NA_real_, n.offsets)
             for(i in 1:n.offsets){
                 offset <- offsets[i]
                 n.windows.minusone <-
-                    (n.years-offset-window.length) %/% window.advance
+                    (n.years - offset - window.length) %/% window.advance
                 max.idx <-
-                    offset + window.length + n.windows.minusone*window.advance
-                n.data[i] <- sum(!is.na(rwi[intersect(good.rows,
-                                                      (1+offset):max.idx), ]))
+                    offset + window.length + n.windows.minusone * window.advance
+                n.data[i] <- sum(!is.na(rwi2[intersect(good.rows,
+                                                      (1 + offset):max.idx), ]))
             }
             ## In case of a tie, choose large offset.
             ## In practice, this prefers recent years.
-            first.start <- offsets[n.offsets-which.max(rev(n.data))+1]+1
+            first.start2 <-
+                offsets[n.offsets - which.max(rev(n.data)) + 1] + 1
         }
-        window.start <- seq(from = first.start,
-                            to = n.years-window.length+1,
+        window.start <- seq(from = first.start2,
+                            to = n.years - window.length + 1,
                             by = window.advance)
+        window.length2 <- window.length
     } else{
         window.start <- 1
-        window.length <- n.years
+        window.length2 <- n.years
     }
 
-    all.years <- as.numeric(rownames(rwi))
+    all.years <- as.numeric(rownames(rwi2))
 
     loop.body <- function(s.idx){
         rbar.tot <- NA_real_
@@ -152,9 +157,9 @@ rwi.stats.running <- function(rwi, ids=NULL, period=c("max", "common"),
 
         ## Location of window
         start.year <- all.years[s.idx]
-        e.idx <- s.idx + window.length - 1
+        e.idx <- s.idx + window.length2 - 1
         end.year <- all.years[e.idx]
-        mid.year <- floor((start.year+end.year)/2)
+        mid.year <- floor((start.year + end.year) / 2)
         year.idx <- s.idx:e.idx
 
         ## See p 138 in C&K
@@ -162,10 +167,10 @@ rwi.stats.running <- function(rwi, ids=NULL, period=c("max", "common"),
         rsum.bt <- 0
         n.bt <- 0
         good.flag <- rep(FALSE, n.trees)
-        for(i in 1:(n.trees-1)){
-            i.data <- rwi[year.idx, cores.of.tree[[i]], drop=FALSE]
-            for(j in (i+1):n.trees){
-                j.data <- rwi[year.idx, cores.of.tree[[j]], drop=FALSE]
+        for(i in 1:(n.trees - 1)){
+            i.data <- rwi2[year.idx, cores.of.tree[[i]], drop=FALSE]
+            for(j in (i + 1):n.trees){
+                j.data <- rwi2[year.idx, cores.of.tree[[j]], drop=FALSE]
                 bt.r.mat <- dplR:::cor.with.limit(min.corr.overlap,
                                                   i.data, j.data)
                 bt.r.mat <- bt.r.mat[!is.na(bt.r.mat)]
@@ -188,7 +193,7 @@ rwi.stats.running <- function(rwi, ids=NULL, period=c("max", "common"),
             if(length(these.cores)==1){ # make simple case fast
                 n.cores.tree[i] <- 1
             } else {
-                these.data <- rwi[year.idx, these.cores, drop=FALSE]
+                these.data <- rwi2[year.idx, these.cores, drop=FALSE]
                 wt.r.vec <-
                     dplR:::cor.with.limit.upper(min.corr.overlap, these.data)
                 wt.r.vec <- wt.r.vec[!is.na(wt.r.vec)]
@@ -198,7 +203,7 @@ rwi.stats.running <- function(rwi, ids=NULL, period=c("max", "common"),
                     n.wt <- n.wt + n.wt.temp
                     ## Solving c (> 0) in the formula n = 0.5 * c * (c-1)
                     ## leads to c = 0.5 + sqrt(0.25+2*n)
-                    n.cores.tree[i] <- 0.5 + sqrt(0.25 + 2*n.wt.temp)
+                    n.cores.tree[i] <- 0.5 + sqrt(0.25 + 2 * n.wt.temp)
                 } else {
                     n.cores.tree[i] <- 1
                 }
@@ -208,7 +213,7 @@ rwi.stats.running <- function(rwi, ids=NULL, period=c("max", "common"),
         ## Mean correlations
         n.tot <- n.wt + n.bt
         if(n.tot > 0)
-            rbar.tot <- (rsum.wt+rsum.bt) / n.tot
+            rbar.tot <- (rsum.wt + rsum.bt) / n.tot
         if(n.wt > 0)
             rbar.wt <- rsum.wt / n.wt
         if(n.bt > 0)
@@ -225,13 +230,13 @@ rwi.stats.running <- function(rwi, ids=NULL, period=c("max", "common"),
             c.eff <- 1
             rbar.eff <- rbar.bt
         } else{
-            c.eff.rproc <- mean(1/n.cores.tree, na.rm=TRUE)
+            c.eff.rproc <- mean(1 / n.cores.tree, na.rm=TRUE)
             c.eff <- 1 / c.eff.rproc # bookkeeping only
-            rbar.eff <- rbar.bt / (rbar.wt + (1-rbar.wt)*c.eff.rproc)
+            rbar.eff <- rbar.bt / (rbar.wt + (1 - rbar.wt) * c.eff.rproc)
         }
         ## EPS is on page 146 of C&K.
         ## In our interpretation of EPS, we use the average number of trees.
-        eps <- n * rbar.eff / ((n-1)*rbar.eff + 1)
+        eps <- n * rbar.eff / ((n - 1) * rbar.eff + 1)
 
         if(running.window){
             c(start.year = start.year, mid.year = mid.year, end.year = end.year,
