@@ -2,13 +2,12 @@
     function(rwl)
 {
     acf1 <- function(x){
-        x <- x[!is.na(x)]
-        ar1 <- acf(x, lag.max=1, plot=FALSE)
+        ar1 <- acf(x[!is.na(x)], lag.max=1, plot=FALSE)
         ar1$acf[2]
     }
     skew <- function(x){
-        x <- x[!is.na(x)]
-        sum((x-mean(x))^3) / (length(x)*sd(x)^3)
+        y <- x[!is.na(x)]
+        sum((y-mean(y))^3) / (length(y)*sd(y)^3)
     }
 
     yr <- as.numeric(rownames(rwl))
