@@ -1,12 +1,13 @@
 `write.crn` <- function(crn, fname, header=NULL, append=FALSE)
 {
     if(ncol(crn) != 2) stop("'crn' must have 2 columns")
+    crn2 <- crn
 
-    if(any(is.na(crn))) {
-        na.flag <- is.na(crn[, 1])
-        crn[na.flag, 2] <- 0
-        crn[na.flag, 1] <- 9.99
-        print(head(crn))
+    if(any(is.na(crn2))) {
+        na.flag <- is.na(crn2[, 1])
+        crn2[na.flag, 2] <- 0
+        crn2[na.flag, 1] <- 9.99
+        print(head(crn2))
     }
 
     if(append) {
@@ -15,13 +16,14 @@
         if(length(header) > 0)
             stop("bad idea to append with 'header'")
     }
-    if(length(header) > 0){
-        if(!is.list(header)) stop("header must be a list")
+    header2 <- header
+    if(length(header2) > 0){
+        if(!is.list(header2)) stop("header must be a list")
         header.names <-
             c("site.id", "site.name", "spp.code", "state.country",
               "spp", "elev", "lat", "long", "first.yr", "last.yr",
               "lead.invs", "comp.date")
-        if(!all(header.names %in% names(header)))
+        if(!all(header.names %in% names(header2)))
             stop("'header' must be a list with the following names: ",
                  paste(dQuote(header.names), collapse = ", "))
         ## Record #1: 1-6 Site ID, 10-61 Site Name, 62-65 Species Code,
@@ -31,20 +33,20 @@
         ## Note: lat-lons are in degrees and minutes, ddmm or dddmm
         ## Record #3: 1-6 Site ID, 10-72 Lead Investigator, 73-80
         ## comp. date
-        header <- lapply(header, as.character)
-        site.id <- header$site.id[1]
-        site.name <- header$site.name[1]
-        spp.code <- header$spp.code[1]
-        state.country <- header$state.country[1]
-        spp <- header$spp[1]
-        elev <- header$elev[1]
-        lat <- header$lat[1]
-        long <- header$long[1]
-        lead.invs <- header$lead.invs[1]
-        comp.date <- header$comp.date[1]
+        header2 <- lapply(header2, as.character)
+        site.id <- header2$site.id[1]
+        site.name <- header2$site.name[1]
+        spp.code <- header2$spp.code[1]
+        state.country <- header2$state.country[1]
+        spp <- header2$spp[1]
+        elev <- header2$elev[1]
+        lat <- header2$lat[1]
+        long <- header2$long[1]
+        lead.invs <- header2$lead.invs[1]
+        comp.date <- header2$comp.date[1]
         lat.long <- ifelse(nchar(long) > 5, paste(lat, long, sep=""),
                            paste(lat, long, sep=" "))
-        yrs <- paste(header$first.yr[1], header$last.yr[1], sep=" ")
+        yrs <- paste(header2$first.yr[1], header2$last.yr[1], sep=" ")
 
         field.name <-
             c("site.id", "site.name", "spp.code", "state.country", "spp",
@@ -68,12 +70,12 @@
         hdr <- c(hdr1, hdr2, hdr3)
     }
 
-    yrs <- as.numeric(rownames(crn))
+    yrs <- as.numeric(rownames(crn2))
     decades.vec <- yrs%/%10 * 10
     decades <- unique(decades.vec)
     n.decades <- length(decades)
     ## 1-6
-    crn.name <- colnames(crn)[1]
+    crn.name <- colnames(crn2)[1]
     crn.width <- nchar(crn.name)
     ## If crn.width > 6, truncate
     if(crn.width > 6)
@@ -91,13 +93,13 @@
         ## Pad to nchar 4 (no leading zero)
         dec.yrs <- formatC(dec.yrs, digits = 0, width = 4, format = "f")
 
-        dec.rwi <- crn[dec.idx, 1]
+        dec.rwi <- crn2[dec.idx, 1]
         ## Pad to nchar 4 (no leading zero)
         dec.rwi <- round(dec.rwi, 3) * 1000
         dec.rwi <- formatC(dec.rwi, digits = 0, width = 4, format = "f")
 
         ## Pad to nchar 3 (no leading zero)
-        dec.samp.depth <- crn[dec.idx, 2]
+        dec.samp.depth <- crn2[dec.idx, 2]
         dec.samp.depth <- formatC(dec.samp.depth,
                                   digits = 0, width = 3, format = "f")
         ## Pad front end
@@ -113,6 +115,6 @@
     dec.str[i] <- paste(dec.str[i],
                         paste(rep("9990  0", 10-n.yrs), collapse=""),
                         sep="")
-    if(length(header) > 0) dec.str <- c(hdr, dec.str)
+    if(length(header2) > 0) dec.str <- c(hdr, dec.str)
     cat(dec.str, file = fname, sep = "\n", append=append)
 }
